@@ -3,7 +3,6 @@ Password generation for the Jupyter Server.
 """
 import getpass
 import hashlib
-import io
 import json
 import os
 import random
@@ -12,9 +11,7 @@ import warnings
 from contextlib import contextmanager
 
 from jupyter_core.paths import jupyter_config_dir
-from traitlets.config import Config
-from traitlets.config import ConfigFileNotFound
-from traitlets.config import JSONFileConfigLoader
+from traitlets.config import Config, ConfigFileNotFound, JSONFileConfigLoader
 
 # Length of the salt in nr of hex chars, which implies salt_len * 4
 # bits of randomness.
@@ -156,14 +153,14 @@ def persist_config(config_file=None, mode=0o600):
 
     yield config
 
-    with io.open(config_file, "w", encoding="utf8") as f:
+    with open(config_file, "w", encoding="utf8") as f:
         f.write(json.dumps(config, indent=2))
 
     try:
         os.chmod(config_file, mode)
     except Exception:
         tb = traceback.format_exc()
-        warnings.warn("Failed to set permissions on %s:\n%s" % (config_file, tb), RuntimeWarning)
+        warnings.warn(f"Failed to set permissions on {config_file}:\n{tb}", RuntimeWarning)
 
 
 def set_password(password=None, config_file=None):
