@@ -15,22 +15,14 @@ from jupyter_client.kernelspec import KernelSpecManager
 from jupyter_client.manager import AsyncKernelManager
 from jupyter_client.managerabc import KernelManagerABC
 from tornado import web
-from tornado.escape import json_decode
-from tornado.escape import json_encode
-from tornado.escape import url_escape
-from tornado.escape import utf8
-from traitlets import default
-from traitlets import DottedObjectName
-from traitlets import Instance
-from traitlets import Type
+from tornado.escape import json_decode, json_encode, url_escape, utf8
+from traitlets import DottedObjectName, Instance, Type, default
 
 from .._tz import UTC
 from ..services.kernels.kernelmanager import AsyncMappingKernelManager
 from ..services.sessions.sessionmanager import SessionManager
-from ..utils import ensure_async
-from ..utils import url_path_join
-from .gateway_client import gateway_request
-from .gateway_client import GatewayClient
+from ..utils import ensure_async, url_path_join
+from .gateway_client import GatewayClient, gateway_request
 
 
 class GatewayMappingKernelManager(AsyncMappingKernelManager):
@@ -80,7 +72,7 @@ class GatewayMappingKernelManager(AsyncMappingKernelManager):
                 kwargs["cwd"] = self.cwd_for_path(path)
 
         km = self.kernel_manager_factory(parent=self, log=self.log)
-        await km.start_kernel(**kwargs)
+        await km.start_kernel(kernel_id=kernel_id, **kwargs)
         kernel_id = km.kernel_id
         self._kernels[kernel_id] = km
 
@@ -376,6 +368,7 @@ class GatewayKernelManager(AsyncKernelManager):
             self.log.debug("Request kernel at: %s" % self.kernel_url)
             try:
                 response = await gateway_request(self.kernel_url, method="GET")
+
             except web.HTTPError as error:
                 if error.status_code == 404:
                     self.log.warning("Kernel not found at: %s" % self.kernel_url)
@@ -442,15 +435,13 @@ class GatewayKernelManager(AsyncKernelManager):
             response = await gateway_request(self.kernels_url, method="POST", body=json_body)
             self.kernel = json_decode(response.body)
             self.kernel_id = self.kernel["id"]
-            self.log.info(
-                "GatewayKernelManager started kernel: {}, args: {}".format(self.kernel_id, kwargs)
-            )
+            self.kernel_url = url_path_join(self.kernels_url, url_escape(str(self.kernel_id)))
+            self.log.info(f"GatewayKernelManager started kernel: {self.kernel_id}, args: {kwargs}")
         else:
             self.kernel_id = kernel_id
+            self.kernel_url = url_path_join(self.kernels_url, url_escape(str(self.kernel_id)))
             self.kernel = await self.refresh_model()
-            self.log.info("GatewayKernelManager using existing kernel: {}".format(self.kernel_id))
-
-        self.kernel_url = url_path_join(self.kernels_url, url_escape(str(self.kernel_id)))
+            self.log.info(f"GatewayKernelManager using existing kernel: {self.kernel_id}")
 
     async def shutdown_kernel(self, now=False, restart=False):
         """Attempts to stop the kernel process cleanly via HTTP."""
@@ -712,7 +703,7 @@ class GatewayKernelClient(AsyncKernelClient):
 
         except BaseException as be:
             if not self._channels_stopped:
-                self.log.warning("Unexpected exception encountered ({})".format(be))
+                self.log.warning(f"Unexpected exception encountered ({be})")
 
         self.log.debug("Response router thread exiting...")
 
