@@ -1,4 +1,3 @@
-# coding: utf-8
 """A tornado based Jupyter server."""
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
@@ -9,7 +8,6 @@ import gettext
 import hashlib
 import hmac
 import inspect
-import io
 import ipaddress
 import json
 import logging
@@ -37,10 +35,10 @@ except ImportError:
     resource = None
 
 from jinja2 import Environment, FileSystemLoader
-
 from jupyter_core.paths import secure_write
-from jupyter_server.transutils import trans, _i18n
-from jupyter_server.utils import run_sync_in_loop, urljoin, pathname2url
+
+from jupyter_server.transutils import _i18n, trans
+from jupyter_server.utils import pathname2url, run_sync_in_loop, urljoin
 
 # the minimum viable tornado version: needs to be kept in sync with setup.py
 MIN_TORNADO = (6, 1, 0)
@@ -52,95 +50,89 @@ try:
 except (ImportError, AttributeError, AssertionError) as e:  # pragma: no cover
     raise ImportError(_i18n("The Jupyter Server requires tornado >=%s.%s.%s") % MIN_TORNADO) from e
 
-from tornado import httpserver
-from tornado import ioloop
-from tornado import web
+from tornado import httpserver, ioloop, web
 from tornado.httputil import url_concat
-from tornado.log import LogFormatter, app_log, access_log, gen_log
+from tornado.log import LogFormatter, access_log, app_log, gen_log
 
 if not sys.platform.startswith("win"):
     from tornado.netutil import bind_unix_socket
 
+from jupyter_client import KernelManager
+from jupyter_client.kernelspec import KernelSpecManager
+from jupyter_client.session import Session
+from jupyter_core.application import JupyterApp, base_aliases, base_flags
+from jupyter_core.paths import jupyter_runtime_dir
+from nbformat.sign import NotebookNotary
+from traitlets import (
+    Any,
+    Bool,
+    Bytes,
+    Dict,
+    Float,
+    Instance,
+    Integer,
+    List,
+    TraitError,
+    Type,
+    Unicode,
+    default,
+    observe,
+    validate,
+)
+from traitlets.config import Config
+from traitlets.config.application import boolean_flag, catch_config_error
+
 from jupyter_server import (
     DEFAULT_JUPYTER_SERVER_PORT,
     DEFAULT_STATIC_FILES_PATH,
     DEFAULT_TEMPLATE_PATH_LIST,
     __version__,
 )
-
-from jupyter_server.base.handlers import MainHandler, RedirectWithParams, Template404
+from jupyter_server._sysinfo import get_sys_info
+from jupyter_server._tz import utcnow
+from jupyter_server.auth.authorizer import AllowAllAuthorizer, Authorizer
+from jupyter_server.auth.login import LoginHandler
+from jupyter_server.auth.logout import LogoutHandler
+from jupyter_server.base.handlers import (
+    FileFindHandler,
+    MainHandler,
+    RedirectWithParams,
+    Template404,
+)
+from jupyter_server.extension.config import ExtensionConfigManager
+from jupyter_server.extension.manager import ExtensionManager
+from jupyter_server.extension.serverextension import ServerExtensionApp
+from jupyter_server.gateway.managers import (
+    GatewayClient,
+    GatewayKernelSpecManager,
+    GatewayMappingKernelManager,
+    GatewaySessionManager,
+)
 from jupyter_server.log import log_request
-from jupyter_server.services.kernels.kernelmanager import (
-    MappingKernelManager,
-    AsyncMappingKernelManager,
-)
 from jupyter_server.services.config import ConfigManager
-from jupyter_server.services.contents.manager import (
-    AsyncContentsManager,
-    ContentsManager,
-)
 from jupyter_server.services.contents.filemanager import (
     AsyncFileContentsManager,
     FileContentsManager,
 )
 from jupyter_server.services.contents.largefilemanager import LargeFileManager
+from jupyter_server.services.contents.manager import (
+    AsyncContentsManager,
+    ContentsManager,
+)
+from jupyter_server.services.kernels.kernelmanager import (
+    AsyncMappingKernelManager,
+    MappingKernelManager,
+)
 from jupyter_server.services.sessions.sessionmanager import SessionManager
-from jupyter_server.gateway.managers import (
-    GatewayMappingKernelManager,
-    GatewayKernelSpecManager,
-    GatewaySessionManager,
-    GatewayClient,
-)
-from jupyter_server.auth.authorizer import Authorizer, AllowAllAuthorizer
-
-from jupyter_server.auth.login import LoginHandler
-from jupyter_server.auth.logout import LogoutHandler
-from jupyter_server.base.handlers import FileFindHandler
-
-from traitlets.config import Config
-from traitlets.config.application import catch_config_error, boolean_flag
-from jupyter_core.application import (
-    JupyterApp,
-    base_flags,
-    base_aliases,
-)
-from jupyter_client import KernelManager
-from jupyter_client.kernelspec import KernelSpecManager
-from jupyter_client.session import Session
-from nbformat.sign import NotebookNotary
-from traitlets import (
-    Any,
-    Dict,
-    Unicode,
-    Integer,
-    List,
-    Bool,
-    Bytes,
-    Instance,
-    TraitError,
-    Type,
-    Float,
-    observe,
-    default,
-    validate,
-)
-from jupyter_core.paths import jupyter_runtime_dir
-from jupyter_server._sysinfo import get_sys_info
-
-from jupyter_server._tz import utcnow
-from jupyter_server.utils import (
-    url_path_join,
-    check_pid,
-    url_escape,
-    unix_socket_in_use,
-    urlencode_unix_socket_path,
-    fetch,
-)
-
-from jupyter_server.extension.serverextension import ServerExtensionApp
-from jupyter_server.extension.manager import ExtensionManager
-from jupyter_server.extension.config import ExtensionConfigManager
 from jupyter_server.traittypes import TypeFromClasses
+from jupyter_server.utils import (
+    check_pid,
+    fetch,
+    unix_socket_in_use,
+    url_escape,
+    url_path_join,
+    urlencode_unix_socket_path,
+)
 
 # Tolerate missing terminado package.
 try:
@@ -256,7 +248,7 @@ class ServerWebApplication(web.Application):
         )
         handlers = self.init_handlers(default_services, settings)
 
-        super(ServerWebApplication, self).__init__(handlers, **settings)
+        super().__init__(handlers, **settings)
 
     def init_settings(
         self,
@@ -512,7 +504,7 @@ def shutdown_server(server_info, timeout=5, log=None):
     if log:
         log.debug("POST request to %sapi/shutdown", url)
 
-    fetch(url, method="POST", headers={"Authorization": "token " + server_info["token"]})
+    fetch(url, method="POST", body=b"", headers={"Authorization": "token " + server_info["token"]})
     # Poll to see if it shut down.
     for _ in range(timeout * 10):
         if not check_pid(pid):
@@ -556,7 +548,7 @@ class JupyterServerStopApp(JupyterApp):
     sock = Unicode("", config=True, help="UNIX socket of the server to be killed.")
 
     def parse_command_line(self, argv=None):
-        super(JupyterServerStopApp, self).parse_command_line(argv)
+        super().parse_command_line(argv)
         if self.extra_args:
             try:
                 self.port = int(self.extra_args[0])
@@ -598,7 +590,7 @@ class JupyterServerStopApp(JupyterApp):
                     return
         current_endpoint = self.sock or self.port
         print(
-            "There is currently no server running on {}".format(current_endpoint),
+            f"There is currently no server running on {current_endpoint}",
             file=sys.stderr,
         )
         print("Ports/sockets currently in use:", file=sys.stderr)
@@ -864,7 +856,7 @@ class ServerApp(JupyterApp):
         s = socket.socket()
         try:
             s.bind(("localhost", 0))
-        except socket.error as e:
+        except OSError as e:
             self.log.warning(
                 _i18n("Cannot bind to localhost, using 127.0.0.1 as default ip\n%s"), e
             )
@@ -997,7 +989,7 @@ class ServerApp(JupyterApp):
     @default("cookie_secret")
     def _default_cookie_secret(self):
         if os.path.exists(self.cookie_secret_file):
-            with io.open(self.cookie_secret_file, "rb") as f:
+            with open(self.cookie_secret_file, "rb") as f:
                 key = f.read()
         else:
             key = encodebytes(os.urandom(32))
@@ -1044,7 +1036,7 @@ class ServerApp(JupyterApp):
             return os.getenv("JUPYTER_TOKEN")
         if os.getenv("JUPYTER_TOKEN_FILE"):
             self._token_generated = False
-            with io.open(os.getenv("JUPYTER_TOKEN_FILE"), "r") as token_file:
+            with open(os.getenv("JUPYTER_TOKEN_FILE")) as token_file:
                 return token_file.read()
         if self.password:
             # no token if password is enabled
@@ -1626,7 +1618,10 @@ class ServerApp(JupyterApp):
         # preferred_dir must be equal or a subdir of root_dir
         if not value.startswith(self.root_dir):
             raise TraitError(
-                trans.gettext("preferred_dir must be equal or a subdir of root_dir: '%r'") % value
+                trans.gettext(
+                    "preferred_dir must be equal or a subdir of root_dir. preferred_dir: '%r' root_dir: '%r'"
+                )
+                % (value, self.root_dir)
             )
 
         return value
@@ -1776,7 +1771,7 @@ class ServerApp(JupyterApp):
 
     def parse_command_line(self, argv=None):
 
-        super(ServerApp, self).parse_command_line(argv)
+        super().parse_command_line(argv)
 
         if self.extra_args:
             arg0 = self.extra_args[0]
@@ -1976,12 +1971,14 @@ class ServerApp(JupyterApp):
             scheme = "http+unix"
             netloc = urlencode_unix_socket_path(self.sock)
         else:
+            if not self.ip:
+                ip = "localhost"
             # Handle nonexplicit hostname.
-            if self.ip in ("", "0.0.0.0", "::"):
+            elif self.ip in ("0.0.0.0", "::"):
                 ip = "%s" % socket.gethostname()
             else:
-                ip = "[{}]".format(self.ip) if ":" in self.ip else self.ip
-            netloc = "{ip}:{port}".format(ip=ip, port=self.port)
+                ip = f"[{self.ip}]" if ":" in self.ip else self.ip
+            netloc = f"{ip}:{self.port}"
             if self.certfile:
                 scheme = "https"
             else:
@@ -2022,7 +2019,7 @@ class ServerApp(JupyterApp):
         parts = self._get_urlparts(include_token=True)
         # Update with custom pieces.
         if not self.sock:
-            parts = parts._replace(netloc="127.0.0.1:{port}".format(port=self.port))
+            parts = parts._replace(netloc=f"127.0.0.1:{self.port}")
         return parts.geturl()
 
     @property
@@ -2276,7 +2273,7 @@ class ServerApp(JupyterApp):
         try:
             sock = bind_unix_socket(self.sock, mode=int(self.sock_mode.encode(), 8))
             self.http_server.add_socket(sock)
-        except socket.error as e:
+        except OSError as e:
             if e.errno == errno.EADDRINUSE:
                 self.log.warning(_i18n("The socket %s is already in use.") % self.sock)
                 return False
@@ -2293,7 +2290,7 @@ class ServerApp(JupyterApp):
         for port in random_ports(self.port, self.port_retries + 1):
             try:
                 self.http_server.listen(port, self.ip)
-            except socket.error as e:
+            except OSError as e:
                 if e.errno == errno.EADDRINUSE:
                     if self.port_retries:
                         self.log.info(
@@ -2389,7 +2386,7 @@ class ServerApp(JupyterApp):
         self._init_asyncio_patch()
         # Parse command line, load ServerApp config files,
         # and update ServerApp config.
-        super(ServerApp, self).initialize(argv=argv)
+        super().initialize(argv=argv)
         if self._dispatching:
             return
         # Then, use extensions' config loading mechanism to
@@ -2655,7 +2652,7 @@ class ServerApp(JupyterApp):
         threading.Thread(target=target).start()
 
     def start_app(self):
-        super(ServerApp, self).start()
+        super().start()
 
         if not self.allow_root:
             # check if we are running as root, and abort if it's not allowed
@@ -2795,7 +2792,7 @@ def list_running_servers(runtime_dir=None, log=None):
 
     for file_name in os.listdir(runtime_dir):
         if re.match("jpserver-(.+).json", file_name):
-            with io.open(os.path.join(runtime_dir, file_name), encoding="utf-8") as f:
+            with open(os.path.join(runtime_dir, file_name), encoding="utf-8") as f:
                 info = json.load(f)
 
             # Simple check whether that process is really still running
