@@ -4,11 +4,9 @@ Utilities for file-based Contents/Checkpoints managers.
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import errno
-import io
 import os
 import shutil
-from base64 import decodebytes
-from base64 import encodebytes
+from base64 import decodebytes, encodebytes
 from contextlib import contextmanager
 from functools import partial
 
@@ -18,8 +16,7 @@ from tornado.web import HTTPError
 from traitlets import Bool
 from traitlets.config import Configurable
 
-from jupyter_server.utils import to_api_path
-from jupyter_server.utils import to_os_path
+from jupyter_server.utils import to_api_path, to_os_path
 
 
 def replace_file(src, dst):
@@ -107,9 +104,9 @@ def atomic_writing(path, text=True, encoding="utf-8", log=None, **kwargs):
     if text:
         # Make sure that text files have Unix linefeeds by default
         kwargs.setdefault("newline", "\n")
-        fileobj = io.open(path, "w", encoding=encoding, **kwargs)
+        fileobj = open(path, "w", encoding=encoding, **kwargs)
     else:
-        fileobj = io.open(path, "wb", **kwargs)
+        fileobj = open(path, "wb", **kwargs)
 
     try:
         yield fileobj
@@ -155,9 +152,9 @@ def _simple_writing(path, text=True, encoding="utf-8", log=None, **kwargs):
     if text:
         # Make sure that text files have Unix linefeeds by default
         kwargs.setdefault("newline", "\n")
-        fileobj = io.open(path, "w", encoding=encoding, **kwargs)
+        fileobj = open(path, "w", encoding=encoding, **kwargs)
     else:
-        fileobj = io.open(path, "wb", **kwargs)
+        fileobj = open(path, "wb", **kwargs)
 
     try:
         yield fileobj
@@ -198,7 +195,7 @@ class FileManagerMixin(Configurable):
     def open(self, os_path, *args, **kwargs):
         """wrapper around io.open that turns permission errors into 403"""
         with self.perm_to_403(os_path):
-            with io.open(os_path, *args, **kwargs) as f:
+            with open(os_path, *args, **kwargs) as f:
                 yield f
 
     @contextmanager
@@ -279,7 +276,7 @@ class FileManagerMixin(Configurable):
             if not self.use_atomic_writing or not os.path.exists(tmp_path):
                 raise HTTPError(
                     400,
-                    "Unreadable Notebook: %s %r" % (os_path, e_orig),
+                    f"Unreadable Notebook: {os_path} {e_orig!r}",
                 )
 
             # Move the bad file aside, restore the intermediate, and try again.
@@ -343,7 +340,7 @@ class FileManagerMixin(Configurable):
                 b64_bytes = content.encode("ascii")
                 bcontent = decodebytes(b64_bytes)
         except Exception as e:
-            raise HTTPError(400, "Encoding error saving %s: %s" % (os_path, e)) from e
+            raise HTTPError(400, f"Encoding error saving {os_path}: {e}") from e
 
         with self.atomic_writing(os_path, text=False) as f:
             f.write(bcontent)
@@ -384,7 +381,7 @@ class AsyncFileManagerMixin(FileManagerMixin):
             if not self.use_atomic_writing or not os.path.exists(tmp_path):
                 raise HTTPError(
                     400,
-                    "Unreadable Notebook: %s %r" % (os_path, e_orig),
+                    f"Unreadable Notebook: {os_path} {e_orig!r}",
                 )
 
             # Move the bad file aside, restore the intermediate, and try again.
@@ -451,7 +448,7 @@ class AsyncFileManagerMixin(FileManagerMixin):
                 b64_bytes = content.encode("ascii")
                 bcontent = decodebytes(b64_bytes)
         except Exception as e:
-            raise HTTPError(400, "Encoding error saving %s: %s" % (os_path, e)) from e
+            raise HTTPError(400, f"Encoding error saving {os_path}: {e}") from e
 
         with self.atomic_writing(os_path, text=False) as f:
             await run_sync(f.write, bcontent)
