@@ -2,20 +2,22 @@
 
 Preliminary documentation at https://github.com/ipython/ipython/wiki/IPEP-27%3A-Contents-Service
 """
-
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-
 import json
 
+try:
+    from jupyter_client.jsonutil import json_default
+except ImportError:
+    from jupyter_client.jsonutil import date_default as json_default
+
 from tornado import web
 
-from jupyter_server.utils import url_path_join, url_escape, ensure_async
-from jupyter_client.jsonutil import date_default
+from jupyter_server.auth import authorized
+from jupyter_server.base.handlers import APIHandler, JupyterHandler, path_regex
+from jupyter_server.utils import ensure_async, url_escape, url_path_join
 
-from jupyter_server.base.handlers import (
-    JupyterHandler, APIHandler, path_regex,
-)
+AUTH_RESOURCE = "contents"
 
 
 def validate_model(model, expect_content):
@@ -40,32 +42,31 @@ def validate_model(model, expect_content):
     if missing:
         raise web.HTTPError(
             500,
-            u"Missing Model Keys: {missing}".format(missing=missing),
+            f"Missing Model Keys: {missing}",
         )
 
-    maybe_none_keys = ['content', 'format']
+    maybe_none_keys = ["content", "format"]
     if expect_content:
         errors = [key for key in maybe_none_keys if model[key] is None]
         if errors:
             raise web.HTTPError(
                 500,
-                u"Keys unexpectedly None: {keys}".format(keys=errors),
+                f"Keys unexpectedly None: {errors}",
             )
     else:
-        errors = {
-            key: model[key]
-            for key in maybe_none_keys
-            if model[key] is not None
-        }
+        errors = {key: model[key] for key in maybe_none_keys if model[key] is not None}
         if errors:
             raise web.HTTPError(
                 500,
-                u"Keys unexpectedly not None: {keys}".format(keys=errors),
+                f"Keys unexpectedly not None: {errors}",
             )
 
 
-class ContentsHandler(APIHandler):
+class ContentsAPIHandler(APIHandler):
+    auth_resource = AUTH_RESOURCE
 
+
+class ContentsHandler(ContentsAPIHandler):
     def location_url(self, path):
         """Return the full URL location of a file.
 
@@ -74,62 +75,69 @@ class ContentsHandler(APIHandler):
         path : unicode
             The API path of the file, such as "foo/bar.txt".
         """
-        return url_path_join(
-            self.base_url, 'api', 'contents', url_escape(path)
-        )
+        return url_path_join(self.base_url, "api", "contents", url_escape(path))
 
     def _finish_model(self, model, location=True):
         """Finish a JSON request with a model, setting relevant headers, etc."""
         if location:
-            location = self.location_url(model['path'])
-            self.set_header('Location', location)
-        self.set_header('Last-Modified', model['last_modified'])
-        self.set_header('Content-Type', 'application/json')
-        self.finish(json.dumps(model, default=date_default))
+            location = self.location_url(model["path"])
+            self.set_header("Location", location)
+        self.set_header("Last-Modified", model["last_modified"])
+        self.set_header("Content-Type", "application/json")
+        self.finish(json.dumps(model, default=json_default))
 
     @web.authenticated
-    async def get(self, path=''):
+    @authorized
+    async def get(self, path=""):
         """Return a model for a file or directory.
 
         A directory model contains a list of models (without content)
         of the files and directories it contains.
         """
-        path = path or ''
-        type = self.get_query_argument('type', default=None)
-        if type not in {None, 'directory', 'file', 'notebook'}:
-            raise web.HTTPError(400, u'Type %r is invalid' % type)
+        path = path or ""
+        type = self.get_query_argument("type", default=None)
+        if type not in {None, "directory", "file", "notebook"}:
+            raise web.HTTPError(400, "Type %r is invalid" % type)
 
-        format = self.get_query_argument('format', default=None)
-        if format not in {None, 'text', 'base64'}:
-            raise web.HTTPError(400, u'Format %r is invalid' % format)
-        content = self.get_query_argument('content', default='1')
-        if content not in {'0', '1'}:
-            raise web.HTTPError(400, u'Content %r is invalid' % content)
+        format = self.get_query_argument("format", default=None)
+        if format not in {None, "text", "base64"}:
+            raise web.HTTPError(400, "Format %r is invalid" % format)
+        content = self.get_query_argument("content", default="1")
+        if content not in {"0", "1"}:
+            raise web.HTTPError(400, "Content %r is invalid" % content)
         content = int(content)
 
-        model = await ensure_async(self.contents_manager.get(
-            path=path, type=type, format=format, content=content,
-        ))
+        model = await ensure_async(
+            self.contents_manager.get(
+                path=path,
+                type=type,
+                format=format,
+                content=content,
+            )
+        )
         validate_model(model, expect_content=content)
         self._finish_model(model, location=False)
 
     @web.authenticated
-    async def patch(self, path=''):
+    @authorized
+    async def patch(self, path=""):
         """PATCH renames a file or directory without re-uploading content."""
         cm = self.contents_manager
         model = self.get_json_body()
         if model is None:
-            raise web.HTTPError(400, u'JSON body missing')
+            raise web.HTTPError(400, "JSON body missing")
         model = await ensure_async(cm.update(model, path))
         validate_model(model, expect_content=False)
         self._finish_model(model)
 
     async def _copy(self, copy_from, copy_to=None):
         """Copy a file, optionally specifying a target directory."""
-        self.log.info(u"Copying {copy_from} to {copy_to}".format(
-            copy_from=copy_from,
-            copy_to=copy_to or '',
-        ))
+        self.log.info(
+            "Copying {copy_from} to {copy_to}".format(
+                copy_from=copy_from,
+                copy_to=copy_to or "",
+            )
+        )
         model = await ensure_async(self.contents_manager.copy(copy_from, copy_to))
         self.set_status(201)
         validate_model(model, expect_content=False)
@@ -137,17 +145,18 @@ class ContentsHandler(APIHandler):
 
     async def _upload(self, model, path):
         """Handle upload of a new file to path"""
-        self.log.info(u"Uploading file to %s", path)
+        self.log.info("Uploading file to %s", path)
         model = await ensure_async(self.contents_manager.new(model, path))
         self.set_status(201)
         validate_model(model, expect_content=False)
         self._finish_model(model)
 
-    async def _new_untitled(self, path, type='', ext=''):
+    async def _new_untitled(self, path, type="", ext=""):
         """Create a new, empty untitled entity"""
-        self.log.info(u"Creating new %s in %s", type or 'file', path)
-        model = await ensure_async(self.contents_manager.new_untitled(
-            path=path, type=type, ext=ext))
+        self.log.info("Creating new %s in %s", type or "file", path)
+        model = await ensure_async(
+            self.contents_manager.new_untitled(path=path, type=type, ext=ext)
+        )
         self.set_status(201)
         validate_model(model, expect_content=False)
         self._finish_model(model)
@@ -156,13 +165,14 @@ class ContentsHandler(APIHandler):
         """Save an existing file."""
         chunk = model.get("chunk", None)
         if not chunk or chunk == -1:  # Avoid tedious log information
-            self.log.info(u"Saving file at %s", path)
+            self.log.info("Saving file at %s", path)
         model = await ensure_async(self.contents_manager.save(model, path))
         validate_model(model, expect_content=False)
         self._finish_model(model)
 
     @web.authenticated
-    async def post(self, path=''):
+    @authorized
+    async def post(self, path=""):
         """Create a new file in the specified path.
 
         POST creates new files. The server always decides on the name.
@@ -180,16 +190,12 @@ class ContentsHandler(APIHandler):
         if file_exists:
             raise web.HTTPError(400, "Cannot POST to files, use PUT instead.")
 
-        dir_exists = await ensure_async(cm.dir_exists(path))
-        if not dir_exists:
-            raise web.HTTPError(404, "No such directory: %s" % path)
-
         model = self.get_json_body()
 
         if model is not None:
-            copy_from = model.get('copy_from')
-            ext = model.get('ext', '')
-            type = model.get('type', '')
+            copy_from = model.get("copy_from")
+            ext = model.get("ext", "")
+            type = model.get("type", "")
             if copy_from:
                 await self._copy(copy_from, path)
             else:
@@ -198,7 +204,8 @@ class ContentsHandler(APIHandler):
             await self._new_untitled(path)
 
     @web.authenticated
-    async def put(self, path=''):
+    @authorized
+    async def put(self, path=""):
         """Saves the file in the location specified by name and path.
 
         PUT is very similar to POST, but the requester specifies the name,
@@ -211,7 +218,7 @@ class ContentsHandler(APIHandler):
         """
         model = self.get_json_body()
         if model:
-            if model.get('copy_from'):
+            if model.get("copy_from"):
                 raise web.HTTPError(400, "Cannot copy with PUT, only POST")
             exists = await ensure_async(self.contents_manager.file_exists(path))
             if exists:
@@ -222,41 +229,48 @@ class ContentsHandler(APIHandler):
             await self._new_untitled(path)
 
     @web.authenticated
-    async def delete(self, path=''):
+    @authorized
+    async def delete(self, path=""):
         """delete a file in the given path"""
         cm = self.contents_manager
-        self.log.warning('delete %s', path)
+        self.log.warning("delete %s", path)
         await ensure_async(cm.delete(path))
         self.set_status(204)
         self.finish()
 
 
-class CheckpointsHandler(APIHandler):
-
+class CheckpointsHandler(ContentsAPIHandler):
     @web.authenticated
-    async def get(self, path=''):
+    @authorized
+    async def get(self, path=""):
         """get lists checkpoints for a file"""
         cm = self.contents_manager
         checkpoints = await ensure_async(cm.list_checkpoints(path))
-        data = json.dumps(checkpoints, default=date_default)
+        data = json.dumps(checkpoints, default=json_default)
         self.finish(data)
 
     @web.authenticated
-    async def post(self, path=''):
+    @authorized
+    async def post(self, path=""):
         """post creates a new checkpoint"""
         cm = self.contents_manager
         checkpoint = await ensure_async(cm.create_checkpoint(path))
-        data = json.dumps(checkpoint, default=date_default)
-        location = url_path_join(self.base_url, 'api/contents',
-            url_escape(path), 'checkpoints', url_escape(checkpoint['id']))
-        self.set_header('Location', location)
+        data = json.dumps(checkpoint, default=json_default)
+        location = url_path_join(
+            self.base_url,
+            "api/contents",
+            url_escape(path),
+            "checkpoints",
+            url_escape(checkpoint["id"]),
+        )
+        self.set_header("Location", location)
         self.set_status(201)
         self.finish(data)
 
 
-class ModifyCheckpointsHandler(APIHandler):
-
+class ModifyCheckpointsHandler(ContentsAPIHandler):
     @web.authenticated
+    @authorized
     async def post(self, path, checkpoint_id):
         """post restores a file from a checkpoint"""
         cm = self.contents_manager
@@ -265,6 +279,7 @@ class ModifyCheckpointsHandler(APIHandler):
         self.finish()
 
     @web.authenticated
+    @authorized
     async def delete(self, path, checkpoint_id):
         """delete clears a checkpoint for a given file"""
         cm = self.contents_manager
@@ -275,39 +290,42 @@ class ModifyCheckpointsHandler(APIHandler):
 
 class NotebooksRedirectHandler(JupyterHandler):
     """Redirect /api/notebooks to /api/contents"""
-    SUPPORTED_METHODS = ('GET', 'PUT', 'PATCH', 'POST', 'DELETE')
+
+    SUPPORTED_METHODS = ("GET", "PUT", "PATCH", "POST", "DELETE")
 
     def get(self, path):
         self.log.warning("/api/notebooks is deprecated, use /api/contents")
-        self.redirect(url_path_join(
-            self.base_url,
-            'api/contents',
-            url_escape(path)
-        ))
+        self.redirect(url_path_join(self.base_url, "api/contents", url_escape(path)))
 
     put = patch = post = delete = get
 
 
 class TrustNotebooksHandler(JupyterHandler):
-    """ Handles trust/signing of notebooks """
+    """Handles trust/signing of notebooks"""
 
     @web.authenticated
-    async def post(self,path=''):
+    @authorized(resource=AUTH_RESOURCE)
+    async def post(self, path=""):
         cm = self.contents_manager
         await ensure_async(cm.trust_notebook(path))
         self.set_status(201)
         self.finish()
-#-----------------------------------------------------------------------------
+
+
+# -----------------------------------------------------------------------------
 # URL to handler mappings
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 
 _checkpoint_id_regex = r"(?P<checkpoint_id>[\w-]+)"
 
+
 default_handlers = [
     (r"/api/contents%s/checkpoints" % path_regex, CheckpointsHandler),
-    (r"/api/contents%s/checkpoints/%s" % (path_regex, _checkpoint_id_regex),
-        ModifyCheckpointsHandler),
+    (
+        rf"/api/contents{path_regex}/checkpoints/{_checkpoint_id_regex}",
+        ModifyCheckpointsHandler,
+    ),
     (r"/api/contents%s/trust" % path_regex, TrustNotebooksHandler),
     (r"/api/contents%s" % path_regex, ContentsHandler),
     (r"/api/notebooks/?(.*)", NotebooksRedirectHandler),
